@@ -8,6 +8,13 @@ MIME::Body - the body of a MIME message
 
 =head1 SYNOPSIS
 
+Before reading further, you should see L<MIME::Tools> to make sure that 
+you understand where this module fits into the grand scheme of things.
+Go on, do it now.  I'll wait.
+
+Ready?  Ok...
+
+
 =head2 Obtaining bodies
 
    ### Get the bodyhandle of a MIME::Entity object:
@@ -135,7 +142,7 @@ use IO::Scalar;
 use Carp;
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5.204 $, 10;
+$VERSION = substr q$Revision: 5.205 $, 10;
 
 
 #------------------------------
@@ -664,7 +671,7 @@ to the use of FileHandles.
 
 =head1 VERSION
 
-$Revision: 5.204 $ $Date: 2000/09/05 04:03:18 $
+$Revision: 5.205 $ $Date: 2000/09/21 05:54:12 $
 
 =cut
 
